# autogenerated module
from typing import ClassVar

from ..core import resource as res
from ..models import discovery_v1beta1 as m_discovery_v1beta1


class EndpointSlice(res.NamespacedResourceG, m_discovery_v1beta1.EndpointSlice):
    """* **Extends**: ``models.discovery_v1beta1.EndpointSlice``
       * **Type**: Namespaced Resource
       * **Accepted client methods**: `delete`, `deletecollection`, `get`, `list` all, `watch` all, `list`, `patch`, `create`, `replace`, `watch`
    """
    _api_info = res.ApiInfo(
        resource=res.ResourceDef('discovery.k8s.io', 'v1beta1', 'EndpointSlice'),
        plural='endpointslices',
        verbs=['delete', 'deletecollection', 'get', 'global_list', 'global_watch', 'list', 'patch', 'post', 'put', 'watch'],
    )

