# autogenerated module
from typing import ClassVar

from ..core import resource as res
from ..models import admissionregistration_v1beta1 as m_admissionregistration_v1beta1


class MutatingWebhookConfiguration(res.GlobalResource, m_admissionregistration_v1beta1.MutatingWebhookConfiguration):
    """* **Extends**: ``models.admissionregistration_v1beta1.MutatingWebhookConfiguration``
       * **Type**: Global Resource
       * **Accepted client methods**: `delete`, `deletecollection`, `get`, `list`, `patch`, `create`, `replace`, `watch`
    """
    _api_info = res.ApiInfo(
        resource=res.ResourceDef('admissionregistration.k8s.io', 'v1beta1', 'MutatingWebhookConfiguration'),
        plural='mutatingwebhookconfigurations',
        verbs=['delete', 'deletecollection', 'get', 'list', 'patch', 'post', 'put', 'watch'],
    )


class ValidatingWebhookConfiguration(res.GlobalResource, m_admissionregistration_v1beta1.ValidatingWebhookConfiguration):
    """* **Extends**: ``models.admissionregistration_v1beta1.ValidatingWebhookConfiguration``
       * **Type**: Global Resource
       * **Accepted client methods**: `delete`, `deletecollection`, `get`, `list`, `patch`, `create`, `replace`, `watch`
    """
    _api_info = res.ApiInfo(
        resource=res.ResourceDef('admissionregistration.k8s.io', 'v1beta1', 'ValidatingWebhookConfiguration'),
        plural='validatingwebhookconfigurations',
        verbs=['delete', 'deletecollection', 'get', 'list', 'patch', 'post', 'put', 'watch'],
    )

